drawBaseline: Draw Ages Using the Inverse CDF Method from the baseline data

View source: R/imputeAges.R

drawBaselineR Documentation

Draw Ages Using the Inverse CDF Method from the baseline data

Description

This function draws ages using the inverse CDF method from baseline data.

Usage

drawBaseline(baseline_data)

Arguments

baseline_data

A data frame containing baseline data with columns 'cum_prob' and 'age'.

Value

A single age value drawn from the baseline data.


penetrance documentation built on Sept. 9, 2026, 1:07 a.m.